@@ -44,6 +44,7 @@ from .connect_to_cloud import (
 from .core import RecceContext, default_context, load_context
 from .event import get_recce_api_token, log_api_event, log_single_env_event
 from .exceptions import RecceException
+from .github import is_github_codespace
 from .models.types import CllData
 from .run import load_preset_checks
 from .state import RecceShareStateManager, RecceStateLoader
@@ -185,7 +186,7 @@ app = FastAPI(lifespan=lifespan)
 
 def verify_json_file(file_path: str) -> bool:
     try:
-        with open(file_path, "r") as f:
+        with open(file_path, "r", encoding="utf-8") as f:
             json.load(f)
     except Exception:
         return False
@@ -282,6 +283,7 @@ class RecceInstanceInfoOut(BaseModel):
     authed: bool
     lifetime_expired_at: Optional[datetime] = None
     share_url: Optional[str] = None
+    session_id: Optional[str] = None
 
 
 @app.get("/api/instance-info", response_model=RecceInstanceInfoOut, response_model_exclude_none=True)
@@ -301,6 +303,7 @@ async def recce_instance_info():
         "authed": True if api_token else False,
         "lifetime_expired_at": app_state.lifetime_expired_at,  # UTC timezone
         "share_url": app_state.share_url,
+        "session_id": app_state.state_loader.session_id if app_state.state_loader else None,
         # TODO: Add more instance info which won't change during the instance lifecycle
         # review_mode
         # cloud_mode
@@ -328,6 +331,7 @@ async def get_info():
     """
     context = default_context()
     demo = os.environ.get("DEMO", False)
+    is_codespace = is_github_codespace()
 
     if demo:
         state = context.export_demo_state()
@@ -352,6 +356,7 @@ async def get_info():
             "pull_request": state.pull_request.to_dict() if state.pull_request else None,
             "lineage": lineage_diff,
             "demo": bool(demo),
+            "codespace": bool(is_codespace),
             "cloud_mode": context.state_loader.cloud_mode,
             "file_mode": context.state_loader.state_file is not None,
             "filename": filename,
@@ -727,6 +732,7 @@ async def get_user_info():
     except Exception as e:
         raise HTTPException(status_code=400, detail=str(e))
 
+
 api_prefix = "/api"
 app.include_router(check_router, prefix=api_prefix)
 app.include_router(run_router, prefix=api_prefix)
